import {Component} from '@angular/core';
import {CommonService} from "../../../../../provide/common.service";
import {Http, Response} from '@angular/http';
import {Storage} from '@ionic/storage';
import {AppService} from "../../../../../http/http.service";
import {Router, ActivatedRoute} from "@angular/router";

@Component({
    selector: 'page-activityApply',
    templateUrl: 'activityApply.html',
})
export class ActivityApplyPage {

    picture: string;
    isLoad: boolean = false;
    //batches: object[];      //所有批次信息
    batches: Array<String>[];
    activity = {
        activityName: '',
        batchList: [],
        id: '',
        applyCount: null     //批次数量限制
    };          //活动信息
    item = {
        batchName: '',
        batchPerNumber: null,
        activityId: '',
        id: '',
        batchLimitNumber: null,
        hasSignUpCount: null
    };
    role = {
        loginName: ''
    };      //角色信息
    //报名订单
    order = {
        Orderid: '',         //订单id
        Personnumber: 0,    //携带人数
        Orderbz: '',         //报名备注
        Activityid: '',      //关联活动id
        Batchid: '',        //关联批次id
        batchlist: ''
    };
    //页面报名保存展示
    isCover: boolean = false;
    //活动详情显示
    introduce: string;
    //选中的批次的id，默认第一个id
    isSelected: string;
    //报名成功
    isSuccess: boolean = false;
    //报名失败

    //活动须知
    noticeArry: object[];

    pageflag: boolean = false;

    constructor(public router: Router,
                public routerInfo: ActivatedRoute, public storage: Storage,
                public cmonmonSer: CommonService,
                public http: Http,
                public appService: AppService,) {

    }

    //活动介绍限定一行17个字符串，两行57个字符串，多余以省略号代替
    subIntroduce(str: string) {
        if (!str) this.introduce = '';
        if (str.length <= 17) this.introduce = str;
        if (str.length > 17 && str.length <= 25) this.introduce = str.substr(0, 17) + "...";
        if (str.length > 25 && str.length <= 42) this.introduce = str;
        if (str.length > 42) this.introduce = str.substr(0, 42) + "...";
    }

    //初始化显示活动列表
    ionViewDidEnter(): void {
        this.routerInfo.queryParams.subscribe(queryParams => {
                this.activity = queryParams.activity;
                this.item = queryParams.item;
                this.order.Activityid = this.activity.id;
                // //获取角色
                this.storage.get("user").then((value) => {
                    this.role = value;
                });
            }
        )
    }

    //携带人数 数字加减
    add() {
        if (this.order.Personnumber < this.item.batchPerNumber) {
            this.order.Personnumber++;
        }
    }

    next() {
        if (this.order.Personnumber >= 1) {
            this.order.Personnumber--;
        }
    }

    //具体介绍
    hidden() {
        this.isCover = false;
    }

    show() {
        this.isCover = true;
    }

    condirmAlert() {
        this.cmonmonSer.alert('确定提交该活动订单？', (res) => {
            this.confirmOrder();
        })
    }

//报名
    confirmOrder() {
        //验证信息：
        /**0.对于暂未有批次的。
         1.判断携带人数是否超过限额人数。
         leaveNum: 剩余人数
         applyNum：报名批次数量
         **/
        let leaveNum = this.item.batchLimitNumber - this.item.hasSignUpCount;
        let applyNum = 0;
        this.activity.batchList.forEach((res) => {
            if (res.order) {
                applyNum++;
            }
        });
        //报名次数 applyCount 1,2,3,4,5,0-> 不限
        if (this.activity.applyCount > 0) {
            if (applyNum >= this.activity.applyCount) {
                this.cmonmonSer.toast("提交失败，报名批次达到上限");
                return;
            } else if (Number(this.order.Personnumber + 1) > Number(leaveNum)) {
                this.cmonmonSer.toast("报名人数超过了该批次的剩余人数");
                return;
            } else {
                this.submitOrder();
            }
        } else {             //报名（新增）
            this.submitOrder();
        }
    }

    //报名操作
    commitSignUpOrder() {
        this.appService.ObserverHttpPost("/wisdomgroup/modules/order/create", this.order)
            .subscribe((res: Response) => {
                    if (true) {
                        this.isSuccess = true;
                        setTimeout(() => {
                            this.isSuccess = false;
                            // this.navCtrl.push("MyActivityListPage");
                        }, 1000);
                    } else {

                    }
                }, error => {
                }
            );
    }


    submitOrder() {
        this.order.Batchid = this.item.id;
        this.order.Activityid = this.item.activityId;
        this.order.batchlist = this.item.id + ',';
        this.appService.ObserverHttpPostOption("/wisdomgroup/modules/order/create", this.order)
            .subscribe((res: Response) => {
                    if (true) {
                        this.isSuccess = true;
                        //清空 插入
                        // this.navCtrl.push("ActivityDetailPage", {id: this.item.activityId});
                    } else {

                    }
                }, error => {
                }
            );
    }

}
